@@ -3,21 +3,6 @@ import argparse
 
 
 def rsi(prices = None, periods = 14):
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-pr', '--prices', nargs="+", type=float, help='Prices')
-    parser.add_argument('-pe', '--periods', type=int, help='Periods')
-
-    args = parser.parse_args()
-
-
-    if not args.prices is None:
-        prices = args.prices
-    else:
-        if prices is None:
-            raise Exception("Please give prices")
-    if not args.periods is None:
-        periods = args.periods
-
     
     if not periods >= len(prices):
         prices = prices[-periods:]
@@ -33,4 +18,22 @@ def rsi(prices = None, periods = 14):
             
         return rsi
     else:
-        raise ValueError("The price list not acceptable for periods")
\ No newline at end of file
+        raise ValueError(f"The price list not acceptable for {periods} period")
+
+def arguments():
+    prices = None
+    periods = 14
+
+    parser = argparse.ArgumentParser()
+    parser.add_argument('-pr', '--prices', nargs="+", type=float, required=True, help='Prices')
+    parser.add_argument('-pe', '--periods', type=int, help='Periods')
+
+    args = parser.parse_args()
+
+
+    if not args.prices is None:
+        prices = args.prices
+    if not args.periods is None:
+        periods = args.periods
+
+    return rsi(prices=prices, periods=periods)
